@@ -1,7 +1,6 @@
 from django.conf.urls import url
 
 import oscar.apps.dashboard.offers.apps as apps
-from oscar.core.loading import get_class
 
 
 class OffersDashboardConfig(apps.OffersDashboardConfig):
@@ -11,7 +10,9 @@ class OffersDashboardConfig(apps.OffersDashboardConfig):
 
     def ready(self):
         super().ready()
-        self.flash_sale_create_view = get_class('ms_oscar_flash_offer.dashboard.offers.views', 'FlashSaleCreateView')
+        from .views import FlashSaleCreateView
+
+        self.flash_sale_create_view = FlashSaleCreateView
 
     def get_urls(self):
         urls = [
